@@ -1,4 +1,4 @@
-// Copyright (c) 2020-2021, Sylabs Inc. All rights reserved.
+// Copyright (c) 2020-2024, Sylabs Inc. All rights reserved.
 // This software is licensed under a 3-clause BSD license. Please consult the LICENSE.md file
 // distributed with the sources of this project regarding your rights to use or distribute this
 // software.
@@ -6,6 +6,8 @@
 package integrity
 
 import (
+	"crypto"
+
 	"github.com/ProtonMail/go-crypto/openpgp"
 	"github.com/sylabs/sif/v2/pkg/sif"
 )
@@ -14,6 +16,7 @@ import (
 type VerifyResult struct {
 	sig      sif.Descriptor
 	verified []sif.Descriptor
+	keys     []crypto.PublicKey
 	e        *openpgp.Entity
 	err      error
 }
@@ -28,6 +31,11 @@ func (r VerifyResult) Verified() []sif.Descriptor {
 	return r.verified
 }
 
+// Keys returns the public key(s) used to verify the signature.
+func (r VerifyResult) Keys() []crypto.PublicKey {
+	return r.keys
+}
+
 // Entity returns the signing entity, or nil if the signing entity could not be determined.
 func (r VerifyResult) Entity() *openpgp.Entity {
 	return r.e
