@@ -1,4 +1,4 @@
-// Copyright (c) 2020-2024, Sylabs Inc. All rights reserved.
+// Copyright (c) 2020-2026, Sylabs Inc. All rights reserved.
 // This software is licensed under a 3-clause BSD license. Please consult the LICENSE.md file
 // distributed with the sources of this project regarding your rights to use or distribute this
 // software.
@@ -7,7 +7,6 @@ package integrity
 
 import (
 	"bytes"
-	"context"
 	"crypto"
 	"errors"
 	"os"
@@ -78,7 +77,7 @@ func TestOptSignGroupObjects(t *testing.T) {
 			}
 
 			if err == nil {
-				var got []uint32
+				got := make([]uint32, 0, len(gs.ods))
 				for _, od := range gs.ods {
 					got = append(got, od.ID())
 				}
@@ -339,7 +338,7 @@ func TestGroupSigner_Sign(t *testing.T) {
 
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			di, err := tt.gs.sign(context.Background())
+			di, err := tt.gs.sign(t.Context())
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("got error %v, want %v", err, tt.wantErr)
 			}
@@ -558,7 +557,7 @@ func TestNewSigner(t *testing.T) {
 					if want, ok := tt.wantGroupObjects[groupID]; !ok {
 						t.Errorf("unexpected signer for group ID %v", groupID)
 					} else {
-						var got []uint32
+						got := make([]uint32, 0, len(signer.ods))
 						for _, od := range signer.ods {
 							got = append(got, od.ID())
 						}
